@@ -77,9 +77,9 @@ GtkWidget * empathy_individual_menu_new (FolksIndividual *individual,
     EmpathyIndividualStore *store);
 
 GtkWidget * empathy_individual_audio_call_menu_item_new (
-    FolksIndividual *individual);
+    EmpathyIndividualMenu *self, FolksIndividual *individual);
 GtkWidget * empathy_individual_video_call_menu_item_new (
-    FolksIndividual *individual);
+    EmpathyIndividualMenu *self, FolksIndividual *individual);
 
 G_END_DECLS
 
