@@ -415,7 +415,7 @@ empathy_account_manager_get_accounts_connected (gboolean *connecting)
 
   manager = tp_account_manager_dup ();
 
-  if (G_UNLIKELY (!tp_account_manager_is_prepared (manager,
+  if (G_UNLIKELY (!tp_proxy_is_prepared (manager,
           TP_ACCOUNT_MANAGER_FEATURE_CORE)))
     g_critical (G_STRLOC ": %s called before AccountManager ready", G_STRFUNC);
 
@@ -946,6 +946,26 @@ create_individual_from_persona (FolksPersona *persona)
   return individual;
 }
 
+FolksIndividual *
+empathy_create_individual_from_tp_contact (TpContact *contact)
+{
+  TpfPersona *persona;
+  FolksIndividual *individual;
+
+  persona = tpf_persona_dup_for_contact (contact);
+  if (persona == NULL)
+    {
+      DEBUG ("Failed to get a persona for %s",
+          tp_contact_get_identifier (contact));
+      return NULL;
+    }
+
+  individual = create_individual_from_persona (FOLKS_PERSONA (persona));
+
+  g_object_unref (persona);
+  return individual;
+}
+
 /* Look for a FolksIndividual containing @contact as one of his persona
  * and create one if needed */
 FolksIndividual *
